@@ -6,7 +6,7 @@
 --                    2008-2009 Duncan Coutts
 -- License     :  BSD3
 --
--- Maintainer  :  duncan@haskell.org
+-- Maintainer  :  duncan@community.haskell.org
 -- Portability :  portable
 --
 -----------------------------------------------------------------------------
@@ -17,7 +17,6 @@ import Codec.Archive.Tar.Types
 import Data.Char     (ord)
 import Data.Int      (Int64)
 import Numeric       (readOct)
-import Control.Monad (unless)
 
 import qualified Data.ByteString.Lazy as BS
 import qualified Data.ByteString.Lazy.Char8 as BS.Char8
